<!-- Copyright © SixtyFPS GmbH <info@slint.dev> ; SPDX-License-Identifier: MIT -->

# Getting Started

First, you need `.slint` files, which contain a textual description of your user interface, written in the Slint language.
Next, you embed the `.slint` files in a project written in a supported programming language, like C++, Rust, or JavaScript.

There are three different pathways to get started with Slint:

1. [SlintPad](https://slint.dev/editor) - Use this to get a feel of the Slint language.
   This is a web browser-based tool where you can try Slint out.

2. As a UI Designer, working with Slint files locally, we recommend the following combination of software tools:

   - [Visual Studio Code](https://code.visualstudio.com)
   - [The Slint for Visual Studio Code Extension](https://marketplace.visualstudio.com/items?itemName=Slint.slint)

3. As a Software Developer, integrating Slint into a new or existing code base, choose one of these languages to
   get started:

   - [C++](slint-cpp:index.html)
   - [Rust](slint-rust:index.html)
   - [JavaScript](slint-node:index.html)
